@@ -9,4 +9,5 @@
 #'     \item{countries}{country names}
 #'     }
 #' 
-"countries"
\ No newline at end of file
+#' @name countries
+NULL
\ No newline at end of file
