@@ -87,12 +87,15 @@ histPlot<-function(histResults, n=20, size.cex=TRUE, size = 5, labelsize = 0.8,a
     scale_edge_colour_discrete(as.factor(E(bsk.network)$color))+
     geom_node_text(aes(label=V(bsk.network)$id, size=labelsize),repel = TRUE)+
     geom_node_point(aes(size = V(bsk.network)$size,color = "grey", alpha=0.1))+
+    scale_x_continuous(labels=as.character(seq(min(Years),max(Years))),breaks=seq(min(Years),max(Years)))+
     scale_color_viridis(discrete = TRUE) +
     theme_minimal()+
     theme(legend.position='none', panel.background = element_rect(fill='gray97', color='grey97'),
-          axis.line.y = element_blank(), axis.text.y=element_blank(),axis.ticks.y=element_blank(),
-          axis.title.y=element_blank(), axis.title.x=element_blank(),
-          panel.grid.minor.y = element_blank(), panel.grid.major.y = element_blank())+
+          axis.line.y = element_blank(), axis.text.y = element_blank(),axis.ticks.y=element_blank(),
+          axis.title.y = element_blank(), axis.title.x = element_blank(),
+          panel.grid.minor.y = element_blank(), panel.grid.major.y = element_blank(),
+          panel.grid.minor.x = element_blank(), axis.text.x=element_text(face="bold"),
+          axis.line.x = element_line(size = 3, colour = "grey80"))+
     labs(title = "Historical Direct Citation Network")
   
   plot(g)
