@@ -238,6 +238,10 @@ AU_CO<-function(M){
   M$AU_CO=gsub(".", "", M$AU_CO, fixed = TRUE)
   M$AU_CO=gsub(";;", ";", M$AU_CO, fixed = TRUE)
   M$AU_CO=gsub("UNITED STATES","USA",M$AU_CO)
+  M$AU_CO=gsub("ENGLAND","UNITED KINGDOM",M$AU_CO)
+  M$AU_CO=gsub("SCOTLAND","UNITED KINGDOM",M$AU_CO)
+  M$AU_CO=gsub("WALES","UNITED KINGDOM",M$AU_CO)
+  M$AU_CO=gsub("NORTH IRELAND","UNITED KINGDOM",M$AU_CO)
   
   if (M$DB[1]=="ISI"){M$AU_CO=removeLastChar(M$AU_CO,last=".")}
   if (M$DB[1]=="SCOPUS"){M$AU_CO=removeLastChar(M$AU_CO,last=";")}
@@ -284,6 +288,10 @@ AU1_CO<-function(M,sep){
   }
   M$AU1_CO=trim(gsub("[[:digit:]]","",M$AU1_CO))
   M$AU1_CO=gsub("UNITED STATES","USA",M$AU1_CO)
+  M$AU1_CO=gsub("ENGLAND","UNITED KINGDOM",M$AU1_CO)
+  M$AU1_CO=gsub("SCOTLAND","UNITED KINGDOM",M$AU1_CO)
+  M$AU1_CO=gsub("WALES","UNITED KINGDOM",M$AU1_CO)
+  M$AU1_CO=gsub("NORTH IRELAND","UNITED KINGDOM",M$AU1_CO)
   #M$AU1_CO=gsub(".", "", M$AU1_CO, fixed = TRUE)
   #M$AU1_CO=gsub(";;", ";", M$AU1_CO, fixed = TRUE)
   return(M)
